import { Inject, Injectable } from '@nestjs/common'
import { securityConfig, SecurityConfig } from 'src/common/configs'
import { hash, compare } from 'bcrypt'

@Injectable()
export class PasswordService {
  constructor(
    @Inject(securityConfig.KEY)
    private secureConfig: SecurityConfig,
  ) {}

  get bcryptSaltRounds(): string | number {
    const saltOrRounds = this.secureConfig.bcryptSaltOrRound

    return Number.isInteger(Number(saltOrRounds))
      ? Number(saltOrRounds)
      : saltOrRounds
  }

  validatePassword(password: string, hashedPassword: string) {
    return compare(password, hashedPassword)
  }

  hashPassword(password: string) {
    return hash(password, this.bcryptSaltRounds)
  }
}
